@@ -26,10 +26,11 @@ class TradePatioClient:
             method="GET",
         ).json()
 
-    def get_exchange_candles(self, exchange, pair, time_frame, period):
+    def get_exchange_candles(self, exchange, pair, time_frame, period, unlimited=False):
         return self.request(
             body={},
-            path="/api/v1/exchange/pair/candles?ex=" + exchange + "&pair=" + pair + "&time-frame=" + time_frame + "&period=" + period,
+            path="/api/v1/exchange/pair/candles?ex=" + exchange + "&pair=" + pair
+                 + "&time-frame=" + time_frame + "&period=" + period + "&unlimited=" + str(unlimited),
             method="GET",
         ).json()
 
